@@ -151,7 +151,7 @@ void csminwel(double (*fcn)(double *x, int n, double **args, int *dims),
 {
    //If gfcn is passed as NULL, numerical gradient is automatically computed.
 
-   int done=0, badg[4], badgh, nogh=1, stuck=0;
+   int done=0, badg[4] = { 0, 0, 0, 0 }, badgh, nogh=1, stuck=0;
    double *x[4], *g[4], f[4], *dg, *dx;
    int retcode[3], fc=0, ih, nn, i;
    int i_dw, verbose_err, terminal_err;  // needed by DW changes
@@ -727,20 +727,22 @@ static void csminit(double *fhat, double *xhat, int *fcount, int *retcode,
             lambda /= factor;
             /* if lambda has already been shrunk as much as possible */
             if (fabs(lambda) < MINLAMB)
-               /* if lambda is positive AND you have not made any improvement
-                  try going against gradient, which may be inaccurate */
-               if ((lambda > 0) && (f0 <= *fhat))
+              {
+                /* if lambda is positive AND you have not made any improvement
+                   try going against gradient, which may be inaccurate */
+                if ((lambda > 0) && (f0 <= *fhat))
                   lambda = -lambda*pow(factor,6);
-               else {
+                else {
                   /* if lambda is negative: let it be known and quit trying */
                   if (lambda < 0)
-                     *retcode = 6;
+                    *retcode = 6;
                   /* if you have not made any imporvement:
                      let it be known and quit trying */
                   else
-                     *retcode = 3;
+                    *retcode = 3;
                   done = 1;
-               }
+                }
+              }
          }
          /* If growSignal=1 and lambda positive OR ( lambda>lambdaPeak or lambda negative )
             (note when lambdaPeak=0 the second part only excludes lambda=0)
