@@ -602,7 +602,7 @@ TElliptical* CreateEllipticalFromPosterior_TruncatedGaussian(TVector R, int dim,
   return elliptical;
 }
 
-TElliptical* CreateEllipticalFromPosterior_Gaussian(TVector R, int dim, TVector center, TMatrix scale)
+TElliptical* CreateEllipticalFromPosterior_Gaussian(__attribute__ ((unused)) TVector R, int dim, TVector center, TMatrix scale)
 {
   TElliptical *elliptical=(TElliptical*)NULL;
   TMatrix variance;
@@ -1025,7 +1025,7 @@ void GraphCummulativeDensities(FILE *f, char* filename, TVector R, TElliptical *
   TVector v;
   FILE *f_out;
 
-  if (f_out=f ? f : fopen(filename,"wt"))
+  if ((f_out=f ? f : fopen(filename,"wt")))
     {
       SortVectorAscending(R,R);
       min=ElementV(R,0);
@@ -1138,7 +1138,7 @@ int dw_marginal_data_density_command_line(int nargs, char **args, TStateModel *m
 
   // Posterior draws file
   printf("Processing posterior draws\n");
-  if (filename=dw_ParseString_String(nargs,args,"pf",(char*)NULL))
+  if ((filename=dw_ParseString_String(nargs,args,"pf",(char*)NULL)))
     {
       if (!(f_in=fopen(filename,"rt"))) 
 	{
