@@ -164,7 +164,7 @@ void dw_NextLine(FILE *f, int n)
   else
     {
       while (ptr && (n-- > 0))
-	while (ptr=fgets(buffer,1024 ,f))
+	while ((ptr=fgets(buffer,1024 ,f)))
 	  if (ptr[strlen(ptr)-1] == '\n') break;
       dw_free(buffer);
     }
@@ -284,7 +284,7 @@ char*** dw_ReadDelimitedFile(FILE *f, char* filename, char delimiter, int flag)
   if (f_in)
     {
       do
-	if (v=dw_ReadDelimitedLine(f_in,delimiter,flag))
+	if ((v=dw_ReadDelimitedLine(f_in,delimiter,flag)))
           {
 	    ptr=(struct LineList*)dw_malloc(sizeof(struct LineList));
 	    ptr->line=v;
@@ -407,7 +407,7 @@ PRECISION** dw_ReadDelimitedFile_floating(FILE *f, char* filename, char delimite
   if (f_in)
     {
       do
-	if (x=dw_ReadDelimitedLine_floating(f_in,delimiter,flag,invalid_identifier)) 
+	if ((x=dw_ReadDelimitedLine_floating(f_in,delimiter,flag,invalid_identifier)))
           {
 	    ptr=(struct LineList*)dw_malloc(sizeof(struct LineList));
 	    ptr->line=x;
@@ -556,7 +556,7 @@ int dw_SetFilePosition(FILE *f, char *id)
   if ((n=(int)strlen(id)) > 0)
     {
       pos=ftell(f);
-      while (buffer=dw_ReadLine(f,buffer,&m))
+      while ((buffer=dw_ReadLine(f,buffer,&m)))
 	if (!memcmp(buffer,id,n)) 
 	  {
 	    dw_free(buffer);
@@ -589,7 +589,7 @@ int dw_SetFilePositionNoRewind(FILE *f, char *id)
   int m, n;
   if ((n=(int)strlen(id)) > 0)
     {
-      while (buffer=dw_ReadLine(f,buffer,&m))
+      while ((buffer=dw_ReadLine(f,buffer,&m)))
 	if (!memcmp(buffer,id,n)) 
 	  {
 	    dw_free(buffer);
