@@ -240,7 +240,7 @@ end
 
 % check for external draws, i.e. set pdraws0 for a gsa analysis
 if options_ident.gsa_sample_file
-    GSAFolder = checkpath('gsa',dname);
+    GSAFolder = CheckPath('gsa',dname);
     if options_ident.gsa_sample_file==1
         load([GSAFolder,filesep,fname,'_prior'],'lpmat','lpmat0','istable');
     elseif options_ident.gsa_sample_file==2
@@ -485,7 +485,7 @@ if iload <=0
             kk=0;
             while kk<50 && info(1)
                 kk=kk+1;
-                params = Prior.draw();
+                params = Prior.draw()'; %column vector is expected
                 options_ident.tittxt = 'Random_prior_params'; %title text for graphs and figures
                 % perform identification analysis
                 [ide_moments_point, ide_spectrum_point, ide_minimal_point, ide_hess_point, ide_reducedform_point, ide_dynamic_point, ~, info, error_indicator_point] = ...
