@@ -89,11 +89,7 @@ if T_max > 0
         
         tmp = 0*binding_indicator;
         tmp(1:end-i+1) = binding_indicator(i:end);
-        if ~isoctave && matlab_ver_less_than('9.1') % Automatic broadcasting was introduced in MATLAB R2016b
-            itmp = find(~any(bsxfun(@minus, dictionary.binding_indicator, tmp)));
-        else
-            itmp = find(~any(dictionary.binding_indicator-tmp));
-        end
+        itmp = find(~any(dictionary.binding_indicator-tmp));
         if ~isempty(itmp)
             ireg(i) = itmp;
         else
