@@ -188,8 +188,8 @@ try
                 end
             else
                 % MCE version of the PAC equation.
-                [rhs, growthneutralitycorrection] = write_pac_mce_expectations(eqtags{i}, ispac.name);
-                auxlhs = sprintf('%s_Z', eqtags{i});
+                auxlhs = M_.endo_names{M_.pac.(ispac.name).mce.z1};
+                [rhs, growthneutralitycorrection] = write_pac_mce_expectations(eqtags{i}, ispac.name, auxlhs);
                 if isempty(growthneutralitycorrection)
                     RHS = strrep(RHS, sprintf('pac_expectation(model_name = %s)', ispac.name), auxlhs);
                 else
